==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/ja.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "アクティビティ",
    "Personal activity feed for %s" : "\"%s\" の個人アクティビティフィード",
    "Your feed URL is invalid" : "フィードURLが無効です",
    "Your settings have been updated." : "設定を更新しました。",
    "Mail" : "メール",
    "Stream" : "ストリーム",
    "Activities" : "アクティビティ",
    "Error loading activities" : "アクティビティ読み込みエラー",
    "No activities" : "アクティビティなし",
    ", " : ", ",
    "{parameterList} and {lastParameter}" : "{parameterList} と {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} と {linkStart} それ以外 %n{linkEnd}"],
    "in {directory}" : "{directory}の中",
    "This stream will show events like additions, changes & shares" : "このタイムラインには、追加、変更、共有が表示されます。",
    "There are no events for this filter" : "このフィルターで表示されるイベントはありません。",
    "Today" : "今日",
    "Yesterday" : "昨日",
    "\"remote user\"" : "\"リモートユーザー\"",
    "Activity notification" : "アクティビティ通知",
    "All Activities" : "すべてのアクティビティ",
    "Activities by you" : "あなたのアクティビティ",
    "Activities by others" : "他人のアクティビティ",
    "%s and %s" : "%s と %s",
    "Hello %s," : "%s さんこんにちは、",
    "You are receiving this email because the following things happened at %s" : "%s で以下のような更新がありました。このメールはその内容をお知らせします。",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* と その他 %n 個"],
    "List your own actions in the stream" : "ストリーム上にあなたの活動を表示する",
    "Notify about your own actions via email" : "メールで自分のアクションを通知する",
    "You need to set up your email address before you can receive notification emails." : "通知メールを受け取る前にメールアドレスを設定してください。",
    "Send emails:" : "メールを送信:",
    "Hourly" : "1時間ごと",
    "Daily" : "毎日",
    "Weekly" : "毎週",
    "Activity feed" : "アクティビティフィード",
    "Enable RSS feed" : "RSSフィードを有効にする",
    "No activity yet" : "アクティビティなし",
    "No more events to load" : "これ以上読み込むイベントはありません",
    "Files" : "ファイル"
},
"nplurals=1; plural=0;");

==> owncloud-9.1.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/ja.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "アクティビティ",
    "Activities" : "アクティビティ",
    "Error loading activities" : "アクティビティ読み込みエラー",
    "No activities" : "アクティビティなし",
    "Load more activities" : "さらにアクティビティを読み込み",
    ", " : ", ",
    "{parameterList} and {lastParameter}" : "{parameterList} と {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} と {linkStart} それ以外 %n{linkEnd}"],
    "in {directory}" : "{directory}の中",
    "This stream will show events like additions, changes & shares" : "このタイムラインには、追加、変更、共有が表示されます。",
    "There are no events for this filter" : "このフィルターで表示されるイベントはありません。",
    "Today" : "今日",
    "Yesterday" : "昨日",
    "Personal activity feed for %s" : "\"%s\" の個人アクティビティフィード",
    "Your feed URL is invalid" : "フィードURLが無効です",
    "Your settings have been updated." : "設定を更新しました。",
    "Mail" : "メール",
    "Stream" : "ストリーム",
    "\"remote user\"" : "\"リモートユーザー\"",
    "Activity notification" : "アクティビティ通知",
    "All Activities" : "すべてのアクティビティ",
    "Activities by you" : "あなたのアクティビティ",
    "Activities by others" : "他人のアクティビティ",
    "%s and %s" : "%s と %s",
    "Hello %s," : "%s さんこんにちは、",
    "You are receiving this email because the following things happened at %s" : "%s で以下のような更新がありました。このメールはその内容をお知らせします。",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* と その他 %n 個"],
    "List your own file actions in the stream" : "ストリーム上にあなたのファイルの操作を表示する",
    "Notify about your own actions via email" : "メールで自分のアクションを通知する",
    "You need to set up your email address before you can receive notification emails." : "通知メールを受け取る前にメールアドレスを設定してください。",
    "Send emails:" : "メールを送信:",
    "Hourly" : "1時間ごと",
    "Daily" : "毎日",
    "Weekly" : "毎週",
    "Activity feed" : "アクティビティフィード",
    "Enable RSS feed" : "RSSフィードを有効にする",
    "No activity yet" : "アクティビティなし",
    "No more events to load" : "これ以上読み込むイベントはありません",
    "Files" : "ファイル"
},
"nplurals=1; plural=0;");
